@@ -1,10 +1,10 @@
 package ZMQ::FFI::SocketRole;
-$ZMQ::FFI::SocketRole::VERSION = '1.15';
+$ZMQ::FFI::SocketRole::VERSION = '1.18';
 use FFI::Platypus;
 use FFI::Platypus::Memory qw(malloc);
 
 use ZMQ::FFI::Constants qw(zmq_msg_t_size);
-use ZMQ::FFI::Util qw(current_tid);
+use ZMQ::FFI::Util qw(current_tid zmq_version);
 
 use Moo::Role;
 
@@ -57,6 +57,12 @@ has sockopt_sizes => (
     builder => '_build_sockopt_sizes'
 );
 
+has event_size => (
+    is      => 'ro',
+    lazy    => 1,
+    builder => '_build_event_size'
+);
+
 sub _build_zmq_msg_t {
     my ($self) = @_;
 
@@ -81,6 +87,23 @@ sub _build_sockopt_sizes {
     };
 }
 
+sub _build_event_size {
+    my $ffi = FFI::Platypus->new();
+
+    my ($major, $minor, $patch) = zmq_version();
+
+    my $size;
+
+    if ($major == 3) {
+        $size = $ffi->sizeof('int') * 2 + $ffi->sizeof('opaque');
+    }
+    elsif ($major > 3) {
+        $size = $ffi->sizeof('uint16', 'sint32');
+    }
+
+    return $size;
+}
+
 requires qw(
     connect
     disconnect
@@ -102,6 +125,8 @@ requires qw(
     get
     set
     close
+    monitor
+    recv_event
 );
 
 1;
@@ -118,7 +143,7 @@ ZMQ::FFI::SocketRole
 
 =head1 VERSION
 
-version 1.15
+version 1.18
 
 =head1 AUTHOR
 
@@ -126,7 +151,7 @@ Dylan Cali <calid1984@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Dylan Cali.
+This software is copyright (c) 2022 by Dylan Cali.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
